# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class SchedulableMessageType(str, Enum):
    """
    The message types a user can actually send — the only ones a schedule may carry.  A narrow API-input enum; the controller converts it to ChatMessageType before storing.
    """

    """
    allowed enum values
    """
    TEXT = 'TEXT'
    AUDIO = 'AUDIO'

    @classmethod
    def from_json(cls, json_str: str) -> SchedulableMessageType:
        """Create an instance of SchedulableMessageType from a JSON string"""
        return SchedulableMessageType(json.loads(json_str))


